@@ -53,4 +53,12 @@ gconfig <- function(..., no.readonly = FALSE){
   }
   else value
   
+}
+
+geoserver_base <- function() {
+  "https://cida.usgs.gov/gdp/geoserver"
+}
+
+process_base <- function() {
+  "https://cida.usgs.gov/gdp/process/WebProcessingService"
 }
\ No newline at end of file
